@@ -1,3 +1,4 @@
+#[cfg(feature = "apply")]
 pub mod apply;
 pub mod behead;
 pub mod cat;
@@ -13,6 +14,7 @@ pub mod fmt;
 #[cfg(feature = "foreach")]
 pub mod foreach;
 pub mod frequency;
+#[cfg(feature = "generate")]
 pub mod generate;
 pub mod headers;
 pub mod index;
