@@ -1,4 +1,7 @@
 extern crate crossbeam_channel as channel;
+#[cfg(feature = "selfupdate")]
+#[macro_use]
+extern crate self_update;
 
 use std::borrow::ToOwned;
 use std::env;
@@ -37,7 +40,7 @@ macro_rules! fail {
 macro_rules! command_list {
     () => {
         "
-    apply       Apply series of transformations to a column
+    apply*      Apply series of transformations to a column
     behead      Drop header from CSV file
     cat         Concatenate by row or column
     count       Count records
@@ -51,7 +54,7 @@ macro_rules! command_list {
     fmt         Format CSV output (change field delimiter)
     foreach*    Loop over a CSV file to execute bash commands (*nix only)
     frequency   Show frequency tables
-    generate    Generate test data by profiling a CSV
+    generate*   Generate test data by profiling a CSV
     headers     Show header names
     help        Show this usage message.
     index       Create CSV index for faster access
@@ -75,7 +78,7 @@ macro_rules! command_list {
     table       Align CSV data into columns
     transpose   Transpose rows/columns of CSV data
 
-    * requires foreach/lua feature
+    * optional feature
 "
     };
 }
@@ -93,9 +96,11 @@ Usage:
 
 Options:
     --list        List all commands available.
+    --envlist     List all environment variables with the QSV_ prefix.
+    --update      Update qsv to the latest release (requires selfupdate feature).
     -h, --help    Display this message
     <command> -h  Display the command help message
-    --version     Print version info, mem allocator, num_cpus then exit
+    --version     Print version info, mem allocator, max_jobs, num_cpus then exit
 
 Commands:",
     command_list!()
@@ -105,6 +110,39 @@ Commands:",
 struct Args {
     arg_command: Option<Command>,
     flag_list: bool,
+    flag_envlist: bool,
+    #[allow(dead_code)]
+    flag_update: bool,
+}
+
+#[cfg(feature = "selfupdate")]
+fn get_exec_name() -> Option<String> {
+    std::env::current_exe()
+        .ok()
+        .and_then(|pb| pb.file_name().map(|s| s.to_os_string()))
+        .and_then(|s| s.into_string().ok())
+}
+
+#[cfg(feature = "selfupdate")]
+fn qsv_update() -> Result<(), Box<dyn ::std::error::Error>> {
+    let exec_name = get_exec_name().unwrap();
+    let status = self_update::backends::github::Update::configure()
+        .repo_owner("jqnatividad")
+        .repo_name("qsv")
+        .bin_name(&exec_name)
+        .show_download_progress(true)
+        .show_output(true)
+        .no_confirm(false)
+        .current_version(cargo_crate_version!())
+        .build()?
+        .update()?;
+    let exe_full_path = format!("{:?}", std::env::current_exe().unwrap());
+    println!(
+        "Update status for {}: `{}`!",
+        exe_full_path,
+        status.version()
+    );
+    Ok(())
 }
 
 fn main() {
@@ -118,6 +156,17 @@ fn main() {
     if args.flag_list {
         wout!(concat!("Installed commands:", command_list!()));
         return;
+    } else if args.flag_envlist {
+        util::show_env_vars();
+        return;
+    }
+    #[cfg(feature = "selfupdate")]
+    if args.flag_update {
+        if let Err(err) = qsv_update() {
+            werr!("{}", err);
+            ::std::process::exit(1);
+        }
+        return;
     }
     match args.arg_command {
         None => {
@@ -154,6 +203,7 @@ Please choose one of the following commands:",
 #[derive(Debug, Deserialize)]
 #[serde(rename_all = "lowercase")]
 enum Command {
+    #[cfg(feature = "apply")]
     Apply,
     Behead,
     Cat,
@@ -169,6 +219,7 @@ enum Command {
     #[cfg(feature = "foreach")]
     ForEach,
     Frequency,
+    #[cfg(feature = "generate")]
     Generate,
     Headers,
     Help,
@@ -208,8 +259,9 @@ impl Command {
             )));
         }
         match self {
-            Command::Apply => cmd::apply::run(argv),
             Command::Behead => cmd::behead::run(argv),
+            #[cfg(feature = "apply")]
+            Command::Apply => cmd::apply::run(argv),
             Command::Cat => cmd::cat::run(argv),
             Command::Count => cmd::count::run(argv),
             Command::Dedup => cmd::dedup::run(argv),
@@ -221,6 +273,7 @@ impl Command {
             Command::Flatten => cmd::flatten::run(argv),
             Command::Fmt => cmd::fmt::run(argv),
             Command::Frequency => cmd::frequency::run(argv),
+            #[cfg(feature = "generate")]
             Command::Generate => cmd::generate::run(argv),
             Command::Headers => cmd::headers::run(argv),
             Command::Help => {
