@@ -319,6 +319,9 @@ impl OneSelector {
                 first_record.len() - 1
             }),
             OneSelector::Index(i) => {
+                if first_record.len() == 0 {
+                    return Err("Input is empty.".to_string());
+                }
                 if i < 1 || i > first_record.len() {
                     Err(format!(
                         "Selector index {} is out of \
