@@ -1,3 +1,4 @@
+#![allow(dead_code)]
 use std::borrow::Cow;
 use std::cmp;
 use std::env;
@@ -48,16 +49,25 @@ pub fn version() -> String {
     match (maj, min, pat, pre) {
         (Some(maj), Some(min), Some(pat), Some(pre)) => {
             if pre.is_empty() {
-                return format!("{}.{}.{}-{}-{}", maj, min, pat, malloc_kind, max_jobs());
-            } else {
                 return format!(
                     "{}.{}.{}-{}-{}-{}",
                     maj,
                     min,
                     pat,
+                    malloc_kind,
+                    max_jobs(),
+                    num_cpus()
+                );
+            } else {
+                return format!(
+                    "{}.{}.{}-{}-{}-{}-{}",
+                    maj,
+                    min,
+                    pat,
                     pre,
                     malloc_kind,
-                    max_jobs()
+                    max_jobs(),
+                    num_cpus(),
                 );
             }
         }
@@ -65,6 +75,20 @@ pub fn version() -> String {
     }
 }
 
+pub fn show_env_vars() {
+    let mut env_var_set = false;
+    for (n, v) in env::vars_os() {
+        let env_var = n.into_string().unwrap();
+        if env_var.starts_with("QSV_") {
+            env_var_set = true;
+            println!("{}: {}", env_var, v.into_string().unwrap());
+        }
+    }
+    if !env_var_set {
+        println!("No QSV_ environment variables set.");
+    }
+}
+
 pub fn count_rows(conf: &Config) -> u64 {
     match conf.indexed().unwrap() {
         Some(idx) => idx.count(),
