@@ -32,11 +32,13 @@ macro_rules! rassert_eq {
 
 mod workdir;
 
+#[cfg(feature = "apply")]
 mod test_apply;
 mod test_behead;
 mod test_cat;
-mod test_count;
 mod test_combos;
+mod test_comments;
+mod test_count;
 mod test_dedup;
 mod test_enumerate;
 mod test_exclude;
@@ -55,8 +57,8 @@ mod test_join;
 mod test_lua;
 mod test_partition;
 mod test_pseudo;
-mod test_replace;
 mod test_rename;
+mod test_replace;
 mod test_reverse;
 mod test_sample;
 mod test_search;
